/**
 * DLDI GUI Patcher for Linux
 *
 * This program is an easy to use GUI to patch multiple files at once,
 * created with GTKmm and intended voor Linux users
 *
 * Created by Lucas van Dijk, using an modified version of dldi source,
 * by Michael Chisholm (Chishm)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * @author Lucas van Dijk
 * @version $Id$
 * @license http://www.opensource.org/licenses/gpl-license.php
 */

#include <libglademm/xml.h>
#include <gtkmm.h>
#include <iostream>
#include "uimain.h"
#include "dbusclient.h"

//#define DEBUG

#ifdef ENABLE_NLS
#  include <libintl.h>
#endif

DBus::Glib::BusDispatcher dispatcher;

int main(int argc, char * argv[])
{
	Gtk::Main main(argc, argv);
	
	DBus::default_dispatcher = &dispatcher;
	dispatcher.attach(NULL);
	DBus::Connection conn = DBus::Connection::SessionBus();
	
	try
	{		
		DBusClient client(conn, DBUS_SERVER_PATH, DBUS_SERVER_NAME);
		if(argc > 1)
		{	
			for(int i = 1; i <= argc; i++)
			{
				client.AddFile(argv[i]);
			}
			
			client.Focus();
		}
		else
		{
			client.Focus();
		}
	}
	catch(DBus::Error)
	{
		// Load Glade file
		Glib::RefPtr<Gnome::Glade::Xml> glade_ref = Gnome::Glade::Xml::create(GLADE_FILE, "wndMain");
	
		conn.request_name(DBUS_SERVER_NAME);

		// Create the window object
		DLDIWindow window(conn, glade_ref);
	}

	return 0;
}
